SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN = (function ( self ) {
    var _timeout     = 0;
    var _widget_type = null;
    
    function ____ ( fct ) {
        _timeout += fct;
    }
    
    self.do = function () {
        switch ( __shinken_test_type ) {
            case "00173":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'logo_shinken', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'generate_at', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'timer_icon', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_mode_edit', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "cancel_edit_mode" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "cancel_edit_mode" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        break;
                    case 4:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_back_to_previous_preview" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_back_to_previous_preview" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_back_to_previous_preview" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_back_to_previous_preview', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED_AND_NO_EVENT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'popup_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'button_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_external_links' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, 'popup_external_links', SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        break;
                }
                break;
            case "00175": //MESSAGE D ERREUR ET WARNING
                switch ( __phase ) {
                    case 1:
                        //TEST: height
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "2", 0, 0, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 2 ) );
                        break;
                    case 2:
                        //TEST: width
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 70, 3, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "10", 0, 0, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10 ) );
                        break;
                    case 3:
                        //TEST: position x
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 70, 5 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "0", 0, 0, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 0 ) );
                        break;
                    case 4:
                        //TEST: position y
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [130, 140, 150], 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["0", "10", "20"], 0, 0, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [0, 10, 20] ) );
                        break;
                    case 5:
                        //TEST: type   // a débug une fois que le bug 29) aura été réglé FGAR
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 4, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 4, 0, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["title_widget", "title_widget", "weather_widget"], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, ["title_widget", "separator_widget", "weather_widget"] ) );
                        break;
                    case 6:
                        //label
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "", 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "default" ) );
                        break;
                    case 7:
                    case 32:
                        //text_color
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#ff0000;", 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#FF0000" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "rgb(252, 186, 3)" ) );
                        break;
                    case 8:
                    case 31:
                        //font_zoom_percent
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1.5, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 200 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 20 ) );
                        break;
                    case 9:
                        //left area + right_area display separator
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 3, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 10:
                        //left area + right_area width_percent separator
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1.5, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 110, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "25" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 25 ) );
                        break;
                    case 11:
                        //text_align  separator
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 5, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "left" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "right" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "center" ) );
                        break;
                    case 12:
                        //item_type  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "cluster", 0, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "host" ) );
                        break;
                    case 13:
                        //background  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "status_context_from_webui" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "no_background" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "context_and_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "only_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "context_then_status" ) );
                        break;
                    case 14:
                        //left_area icon_type  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "status_context_from_webui" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "context_then_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "status_then_context" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "only_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "sla_tendency" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "quality_service_icon" ) );
                        break;
                    case 15:
                        //top_right_area icon_type  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "sla_tendency", 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "status_context_from_webui" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "context_then_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "status_then_context" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "only_status" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "quality_service_icon" ) );
                        break;
                    case 16:
                        //top_right_area displayed  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 17:
                        //sla_area displayed  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 18:
                        //sla_area show_icon  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 19:
                    case 28:
                        //name_area  property_used_as_name weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, WIDGET.CONST.WEATHER.ENUM.PROPERTY_USED_AS_NAME.ITEM_NAME ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, WIDGET.CONST.WEATHER.ENUM.PROPERTY_USED_AS_NAME.VISUALISATION_NAME ) );
                        break;
                    case 20:
                    case 29:
                        //name_area nb_lines_max  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "3", 0, 0, 0, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 3 ) );
                        break;
                    case 21:
                    case 30:
                        //name_area vertical_align  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "bottom" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "middle" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "top" ) );
                        break;
                    case 22:
                        //layouts width
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 70, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "10" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "all" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10 ) );
                        break;
                    case 23:
                        //layouts height
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, -10, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "2" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 2 ) );
                        break;
                    case 24:
                        //weather_widget_layout background
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "context_then_status" ) );
                        break;
                    case 25:
                        //left_area icon_type
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "quality_service_icon" ) );
                        break;
                    case 26:
                        //top_right_area icon_type
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "quality_service_icon" ) );
                        break;
                    case 27:
                        //top_right_area  + sla_area displayed  weather
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 5 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 5 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 33:
                    case 40:
                        //external_links links__default_base_url
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto/test_auto", 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto" ) );
                        break;
                    case 34:
                        //external_links links__default_authentication_needed
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 15, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 35:
                    case 41:
                        //links__default_info_bar background_color
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#ff0000;", 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "#FF0000" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "rgb(252, 186, 3)" ) );
                        break;
                    case 36:
                        //links__default_info_bar logo_displayed + chrono_displayed +  generation_time_displayed
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 15, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true ) );
                        break;
                    case 37:
                    case 42:
                        //links__default_info_bar position
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "bottom" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "top" ) );
                        break;
                    case 38:
                        //links link_name
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "", 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "default" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "test_auto" ) );
                        break;
                    case 39:
                        //links authentication_needed + logo_displayed + chrono_displayed + generation_time_displayed
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False", 0, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false", 0, 1, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 0, 0, 0 ) );
                        break;
                    case 43:
                    case 44:
                        //links server_use_ssl
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, EXTERNAL_LINKS.CONST.EXTERNAL_LINK.ENUM.LINK_PROTOCOL.FROM_WEBUI ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, EXTERNAL_LINKS.CONST.EXTERNAL_LINK.ENUM.LINK_PROTOCOL.HTTPS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, EXTERNAL_LINKS.CONST.EXTERNAL_LINK.ENUM.LINK_PROTOCOL.HTTP ) );
                        break;
                    case 45:
                    case 46:
                    case 47:
                        //notifications
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 12, 2, 0, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "Toto", 2, 0, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "False", 0, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, "false", 0, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 0, 0, 0 ) );
                        break;
                }
                break;
            case "00176":
                switch ( __phase ) {
                    case 1:
                        //TEST WARNING DISPLAYED AFTER SAVE AND RELOAD
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.countProblemsInWindow( _timeout, 0, 1, false ) );
                        break;
                    case 2:
                        break;
                    case 3:
                        break;
                }
                break;
            case "00185":
                //TEST BAD FORMAT VARIABLE
                switch ( __phase ) {
                    case 1:  //TEST: title_area ( + layout )
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 1 ) );
                        break;
                    case 2:  //TEST: information_to_display ( + layout )
                    case 3:  //TEST: layout ( + layout )
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 6, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 6, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 6, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 6, 0, 6 ) );
                        break;
                    case 4:
                        //TEST NON CONCLUANT ... LES RETOURS SONT A REVOIR DANS LE CODE... pour le content
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 10, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 10, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 10, 0, 6 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 10, 0, 6 ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, [], 4, 0, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, SHINKEN.TOOLS.TEST_AUTO.XSS_FUNCTION, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, 10, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationCase( _timeout, true, 4 ) );
                        break;
                }
                break;
            case "00186":
                //TEST BAD FORMAT VARIABLE
                switch ( __phase ) {
                    case 1:  //TEST: test 8 line json bad format
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.validationJsonInvalid( _timeout, 4, 8 ) );
                        break;
                }
                break;
            case "00194":
                _widget_type = WIDGET.CONST.TYPE.SEPARATOR;
                switch ( __phase ) {
                    case 1:
                        // LEFT AREA: displayed:true - width: 20 | RIGHT AREA: displayed:true - width: 20
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_mode_edit" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        
                        // LEFT AREA: displayed:false - width: 20 | RIGHT AREA: displayed:true - width: 20
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        
                        // LEFT AREA: displayed:true - width: 0 | RIGHT AREA: displayed:true - width: 20
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        
                        // LEFT AREA: displayed:true - width: 20 | RIGHT AREA: displayed:false - width: 20
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 4 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        
                        // LEFT AREA: displayed:true - width: 20 | RIGHT AREA: displayed:true - width: 0
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 5 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.LEFT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.RIGHT_AREA._KEY, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        break;
                    
                    case 2:
                        // TODO TESTER NOIR AVANT
                        // TITLE AREA: color:"red"
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_mode_edit" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textColor( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, "rgb(255, 0, 0)" ) );
                        break;
                    case 3:  //TEST: WidgetSeparator text align
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.resetJSON( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "button_mode_edit" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.CENTER ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.LEFT ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, "preview_weather" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.textAlign( _timeout, _widget_type, 0, WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TITLE_AREA._KEY, WIDGET.CONST.WEATHER.ENUM.TEXT_ALIGN.RIGHT ) );
                        break;
                }
                break;
            case "00201": //CHECK TOP_RIGHT_AREA_ICON_TYPE VISIBILITY AND CONTENT
                switch ( __phase ) {
                    case 1:
                        var _location = WIDGET.CONST.PARAM.LAYOUT.INFORMATION_TO_DISPLAY.TOP_RIGHT_AREA._KEY;
                        var _widget   = { type: WIDGET.CONST.TYPE.WEATHER, index: 0 };
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.STATUS_THEN_CONTEXT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.STATUS_THEN_CONTEXT ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 2, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.QUALITY_SERVICE_ICON ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 3, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.ONLY_STATUS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.ONLY_STATUS ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 4, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.CONTEXT_THEN_STATUS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.CONTEXT_THEN_STATUS ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 5, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 6, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 7, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 8, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.stateArea( _timeout, _widget.type, _widget.index, _location, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.contentArea( _timeout, _widget.type, _widget.index, _location, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.FROM_WEBUI ) );
                        break;
                }
                break;
            case "00205":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_00205_0", "xx_invalid_user" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_00205_1", "yy_invalid_user" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_00205_2", "zz_invalid_user" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_00205_3" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.ACTION.createWeather( _timeout, "test_auto_00205_4" ) );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB.ACTION.runTryCheck( _timeout, "shinken-evaluate-check-on-sync", "00000000000000000000000000000205", "20000000000000000000000000000205" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_CHECKS.TEST.validWeatherRunningWellLongOutput( _timeout, "00000000000000000000000000000205", "20000000000000000000000000000205", 1 ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_CHECK_TAB.ACTION.runTryCheck( _timeout, "shinken-evaluate-check-on-sync", "00000000000000000000000000000205", "30000000000000000000000000000205" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_CHECKS.TEST.validWeatherPerformanceLongOutput( _timeout, "00000000000000000000000000000205", "30000000000000000000000000000205", 3 ) );
                        break;
                }
                break;
            case "00208":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.STATUS_THEN_CONTEXT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'preview_weather' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 2, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 1, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 0, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'toggle_display_widgets_withs_issues' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 2, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 1, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 0, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'toggle_display_widgets_withs_issues' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 2, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 1, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 0, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 2, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.HAS_WARNING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WEATHER_GRID_CELL.state( _timeout, 1, SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.WEATHER_GRID_CELL.STATE.HAS_ERROR ) );
                        break;
                }
                break;
            case "00209":
                switch ( __phase ) {
                    case 1:
                        //TEST THE CORRECTION ABOUT THE chrono_displayed & generation_time_displayed adding in json unfortunately
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout, 1, undefined, undefined, WIDGET.CONST.WEATHER.ENUM.TOP_RIGHT_AREA_ICON_TYPE.STATUS_THEN_CONTEXT ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_external_links' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'preview_weather' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.countProblemsInWindow( _timeout, 0, 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.countProblemsInJson( _timeout, 0, 0 ) );
                        break;
                }
                break;
            case "00217":
                switch ( __phase ) {
                    case 1:
                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                        break;
                    case 2:
                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone( _timeout ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO.TEST.isConfigEveryone( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.ELEMENT_VISIBILITY_ON_NOT_AUTHENTICATED_VIEW, "1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 0 ) );
                        break;
                    case 6:
                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 0 ) );
                        break;
                    case 8:
                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT_EDITION.ACTION.navigateInTab( _timeout, WINDOW.CONST.ELEMENT.USER_RIGHTS ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.goToMode( _timeout, MANAGER.CONST.STATE.WORK_FLOW.STAGING ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_PROPERTY.ACTION.setValue( _timeout, PROPERTY.CONST.NAME.ELEMENT_VISIBILITY_ON_NOT_AUTHENTICATED_VIEW, "1" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_SHINKEN_ELEMENT.ACTION.saveWithButtonSave( _timeout ) );
                        break;
                    case 11:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 4, 0, 2 ) );
                        break;
                    case 12:
                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor_si", "test_auto_user_executor_si" );
                        break;
                    case 13:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.WIDGET.count( _timeout, 2, 0, 0 ) );
                        break;
                    case 14:
                        _timeout += SHINKEN.TOOLS.TEST_AUTO.changeUser( "test_auto_user_executor", "test_auto_user_executor" );
                        break;
                    
                }
                break;
            case "00219":
                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.open( _timeout, "/service-weather/no_existing" ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.TEST.pathName( _timeout, "/service-weather-not-found/no_existing" ) );
                ____( SHINKEN.TOOLS.TEST_AUTO_OPEN_WINDOW.ACTION.close( _timeout ) );
                break;
            case "00231":
                switch ( __phase ) {
                    case 1:
                        // ALL TRUE
                        _timeout += 2000;
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 90 ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", true, true ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_external_links' ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'popup_external_links' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.mouseEnterLink( _timeout, "002311" ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.TEST.EXTERNAL_LINKS.tooltipOfLinkContainsText( _timeout, "Son : Activé", true  ) );
                        
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", true, true ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_DISABLED ) );
                        //____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE_AND_CHILDREN_DISABLED ) );
                        __do_next = false;
                        break;
                    case 2:
                        _timeout += 2000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 50 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        break;
                    case 3:
                        _timeout += 2000;
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "OFF" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 50 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANEL_WEATHER.TEST.notificationState( _timeout, "TEST-AUTO-00231", false, false ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_PANELS.ACTION.closePanelsModal( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.IFRAME.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.clickOnSubMenu( _timeout, SHINKEN.SCREEN.TYPE.SERVICE_WEATHER, "menu_expand_views_service_weather_full" ) );
                        break;
                }
                break;
            case "00234":
                switch ( __phase ) {
                    case 1:
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.openUserConfiguration( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "blink", "ON" ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU.ACTION.setValueUserConfigurationProperty( _timeout, "volume", 90 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_mode_edit' ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.setJSONInForm( _timeout ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER_EDIT.ACTION.IFRAME.clickOnButton( _timeout, 'button_save' ) );
                        break;
                    case 2:
                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "1" et "1";
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
                            1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
                            1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
                        break;
                    case 3:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        break;
                    case 4:
                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "0" et "1";
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
                            0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
                            1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
                        break;
                    case 5:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        break;
                    case 6:
                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "1" et "0";
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
                            1 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
                            0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
                        break;
                    case 7:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.VISIBLE ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        break;
                    case 8:
                        //CHANGER LE CFG DES NOTIFICATIONS PAR DEFAUT pour mettre en "0" et "0";
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__sound__enabled",
                            0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.COMMON.ACTION.editInConfigFile( _timeout,
                            "/etc/shinken-user/configuration/daemons/brokers/modules/webui/modules/webui_module_service_weather/webui_module_service_weather__default_notifications_settings.cfg",
                            "broker__module_webui__module_service_weather__default_notifications_settings__visual__blink__enabled",
                            0 ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_DAEMON.ARBITER.ACTION.restart( _timeout, false ) );
                        break;
                    case 9:
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "sound_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        ____( SHINKEN.TOOLS.TEST_AUTO_WEATHER.TEST.displayState( _timeout, "blink_notification_container", SHINKEN.TOOLS.TEST_AUTO_WEATHER.CONST.STATE_DISPLAY.HIDDEN ) );
                        break;
                }
                break;
            default:
                ____( SHINKEN.TOOLS.TEST_AUTO_UI_VISU_MENU_RUN.do( _timeout ) );
                break;
            
        }
        return _timeout;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_WEATHER_RUN || {} );
